==> hapi-fhir-structures-dstu3-2.5-sources.jar: org/hl7/fhir/dstu3/model/codesystems/DiscriminatorTypeEnumFactory.java <==
package org.hl7.fhir.dstu3.model.codesystems;

/*
  Copyright (c) 2011+, HL7, Inc.
  All rights reserved.
  
  Redistribution and use in source and binary forms, with or without modification, 
  are permitted provided that the following conditions are met:
  
   * Redistributions of source code must retain the above copyright notice, this 
     list of conditions and the following disclaimer.
   * Redistributions in binary form must reproduce the above copyright notice, 
     this list of conditions and the following disclaimer in the documentation 
     and/or other materials provided with the distribution.
   * Neither the name of HL7 nor the names of its contributors may be used to 
     endorse or promote products derived from this software without specific 
     prior written permission.
  
  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
  INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT 
  NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR 
  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
  POSSIBILITY OF SUCH DAMAGE.
  
*/

// Generated on Mon, Apr 17, 2017 17:38-0400 for FHIR v3.0.1


import org.hl7.fhir.dstu3.model.EnumFactory;

public class DiscriminatorTypeEnumFactory implements EnumFactory<DiscriminatorType> {

  public DiscriminatorType fromCode(String codeString) throws IllegalArgumentException {
    if (codeString == null || "".equals(codeString))
      return null;
    if ("value".equals(codeString))
      return DiscriminatorType.VALUE;
    if ("exists".equals(codeString))
      return DiscriminatorType.EXISTS;
    if ("pattern".equals(codeString))
      return DiscriminatorType.PATTERN;
    if ("type".equals(codeString))
      return DiscriminatorType.TYPE;
    if ("profile".equals(codeString))
      return DiscriminatorType.PROFILE;
    throw new IllegalArgumentException("Unknown DiscriminatorType code '"+codeString+"'");
  }

  public String toCode(DiscriminatorType code) {
    if (code == DiscriminatorType.VALUE)
      return "value";
    if (code == DiscriminatorType.EXISTS)
      return "exists";
    if (code == DiscriminatorType.PATTERN)
      return "pattern";
    if (code == DiscriminatorType.TYPE)
      return "type";
    if (code == DiscriminatorType.PROFILE)
      return "profile";
    return "?";
  }

    public String toSystem(DiscriminatorType code) {
      return code.getSystem();
      }

}

==> hapi-fhir-structures-dstu3-3.6.0-sources.jar: org/hl7/fhir/dstu3/model/codesystems/DiscriminatorTypeEnumFactory.java <==
package org.hl7.fhir.dstu3.model.codesystems;

/*
  Copyright (c) 2011+, HL7, Inc.
  All rights reserved.
  
  Redistribution and use in source and binary forms, with or without modification, 
  are permitted provided that the following conditions are met:
  
   * Redistributions of source code must retain the above copyright notice, this 
     list of conditions and the following disclaimer.
   * Redistributions in binary form must reproduce the above copyright notice, 
     this list of conditions and the following disclaimer in the documentation 
     and/or other materials provided with the distribution.
   * Neither the name of HL7 nor the names of its contributors may be used to 
     endorse or promote products derived from this software without specific 
     prior written permission.
  
  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
  INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT 
  NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR 
  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
  POSSIBILITY OF SUCH DAMAGE.
  
*/

// Generated on Sat, Mar 25, 2017 21:03-0400 for FHIR v3.0.0


import org.hl7.fhir.dstu3.model.EnumFactory;

public class DiscriminatorTypeEnumFactory implements EnumFactory<DiscriminatorType> {

  public DiscriminatorType fromCode(String codeString) throws IllegalArgumentException {
    if (codeString == null || "".equals(codeString))
      return null;
    if ("value".equals(codeString))
      return DiscriminatorType.VALUE;
    if ("exists".equals(codeString))
      return DiscriminatorType.EXISTS;
    if ("pattern".equals(codeString))
      return DiscriminatorType.PATTERN;
    if ("type".equals(codeString))
      return DiscriminatorType.TYPE;
    if ("profile".equals(codeString))
      return DiscriminatorType.PROFILE;
    throw new IllegalArgumentException("Unknown DiscriminatorType code '"+codeString+"'");
  }

  public String toCode(DiscriminatorType code) {
    if (code == DiscriminatorType.VALUE)
      return "value";
    if (code == DiscriminatorType.EXISTS)
      return "exists";
    if (code == DiscriminatorType.PATTERN)
      return "pattern";
    if (code == DiscriminatorType.TYPE)
      return "type";
    if (code == DiscriminatorType.PROFILE)
      return "profile";
    return "?";
  }

    public String toSystem(DiscriminatorType code) {
      return code.getSystem();
      }

}
